layouttools
===========

.. automodule:: abjad.tools.layouttools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.layouttools.SpacingIndication.SpacingIndication

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.layouttools.make_spacing_vector.make_spacing_vector
      ~abjad.tools.layouttools.set_line_breaks_by_line_duration.set_line_breaks_by_line_duration
      ~abjad.tools.layouttools.set_line_breaks_by_line_duration_ge.set_line_breaks_by_line_duration_ge
      ~abjad.tools.layouttools.set_line_breaks_by_line_duration_in_seconds_ge.set_line_breaks_by_line_duration_in_seconds_ge
